module Lotohelp

  # Requests library
  #
  module Concourse
    extend self

    # Get a specific concourse from lottery
    #
    # @example Get the concourse 1010 from megasena
    # Lotohelp::Concourse.get(1010, 'megasena')
    # @return  [ Hash ]
    def self.get(concourse_number, lottery_slug)
      self.validate_params(concourse_number, lottery_slug)

      Request::get("/lotteries/#{lottery_slug}/concourse/#{concourse_number}")
    end

    # Check for hits on a specific concourse
    #
    # @example Check how many hits for [01,02,03] on concourse 1010 from megasena
    # numbers = ["01","02","03"]
    # Lotohelp::Concourse.check(numbers, 1010, 'megasena')
    # @return  [ Hash ]
    def self.check(numbers=nil, concourse_number=nil, lottery_slug=nil)
      self.validate_params(concourse_number, lottery_slug, numbers)

      Request::post("/check/#{lottery_slug}/#{concourse_number}", {dozens: numbers.join('|'), concourse_number: concourse_number, lottery_slug: lottery_slug})
    end

    private

    def self.validate_params(concourse_number=nil, lottery_slug=nil, numbers=nil)
      if !numbers.nil?
        raise ArgumentError.new("Numbers should be an Array, #{numbers.class} given") unless numbers.is_a?(Array)
      end
      raise ArgumentError.new("Concourse number should be an Integer, #{concourse_number.class} given") if concourse_number.nil? || !concourse_number.is_a?(Integer)
      raise ArgumentError.new("Lottery Slug should be an String, #{lottery_slug.class} given") if lottery_slug.nil? || !lottery_slug.is_a?(String)
    end

  end
end
